@@ -2,12 +2,13 @@ package string
 
 import (
 	"bytes"
+	"context"
 
 	"github.com/lmorg/murex/lang/stdio"
 	"github.com/lmorg/murex/lang/types"
 )
 
-func readArray(read stdio.Io, callback func([]byte)) error {
+func readArray(_ context.Context, read stdio.Io, callback func([]byte)) error {
 	b, err := read.ReadAll()
 	if err != nil {
 		return err
@@ -32,7 +33,7 @@ func readArray(read stdio.Io, callback func([]byte)) error {
 	return nil
 }
 
-func readArrayWithType(read stdio.Io, callback func([]byte, string)) error {
+func readArrayWithType(_ context.Context, read stdio.Io, callback func(interface{}, string)) error {
 	b, err := read.ReadAll()
 	if err != nil {
 		return err
