@@ -10,7 +10,9 @@ import (
 	"time"
 
 	"github.com/lmorg/murex/app"
+	"github.com/lmorg/murex/app/whatsnew"
 	"github.com/lmorg/murex/builtins/pipes/term"
+	"github.com/lmorg/murex/config/profile"
 	"github.com/lmorg/murex/debug"
 	"github.com/lmorg/murex/lang"
 	"github.com/lmorg/murex/lang/ref"
@@ -20,6 +22,7 @@ import (
 	"github.com/lmorg/murex/utils"
 	"github.com/lmorg/murex/utils/ansi"
 	"github.com/lmorg/murex/utils/ansititle"
+	globalcache "github.com/lmorg/murex/utils/cache"
 	"github.com/lmorg/murex/utils/cd"
 	"github.com/lmorg/murex/utils/cd/cache"
 	"github.com/lmorg/murex/utils/consts"
@@ -55,6 +58,10 @@ func Start() {
 		}()
 	}
 
+	globalcache.SetPath(profile.ModulePath() + "cache.db")
+	globalcache.InitCache()
+	whatsnew.Display()
+
 	lang.ShellProcess.StartTime = time.Now()
 
 	// disable this for Darwin (macOS) because the messages it pops up might
