@@ -4,12 +4,14 @@ package readline
 // This is used by readline to determine what state the API should
 // return to after the readline event.
 type EventReturn struct {
-	ForwardKey    bool
-	ClearHelpers  bool
-	CloseReadline bool
-	HintText      []rune
-	NewLine       []rune
-	NewPos        int
+	ForwardKey     bool
+	ClearHelpers   bool
+	CloseReadline  bool
+	DisplayPreview bool
+	HintText       []rune
+	NewLine        []rune
+	NewPos         int
+	Callback       func() error
 }
 
 // AddEvent registers a new keypress handler
